@@ -1,8 +1,7 @@
-from sqlglot import exp
+from sqlglot import exp, transforms
 from sqlglot.dialects.dialect import Dialect, no_ilike_sql
-from sqlglot import transforms
-from sqlglot.helper import csv
 from sqlglot.generator import Generator
+from sqlglot.helper import csv
 from sqlglot.tokens import Tokenizer, TokenType
 
 
@@ -13,12 +12,16 @@ def _limit_sql(self, expression):
 class Oracle(Dialect):
     class Generator(Generator):
         TYPE_MAPPING = {
+            **Generator.TYPE_MAPPING,
             exp.DataType.Type.TINYINT: "NUMBER",
             exp.DataType.Type.SMALLINT: "NUMBER",
             exp.DataType.Type.INT: "NUMBER",
             exp.DataType.Type.BIGINT: "NUMBER",
             exp.DataType.Type.DECIMAL: "NUMBER",
+            exp.DataType.Type.DOUBLE: "DOUBLE PRECISION",
+            exp.DataType.Type.TEXT: "VARCHAR2",
             exp.DataType.Type.VARCHAR: "VARCHAR2",
+            exp.DataType.Type.NVARCHAR: "NVARCHAR2",
         }
 
         TRANSFORMS = {
@@ -54,4 +57,6 @@ class Oracle(Dialect):
         KEYWORDS = {
             **Tokenizer.KEYWORDS,
             "TOP": TokenType.TOP,
+            "VARCHAR2": TokenType.VARCHAR,
+            "NVARCHAR2": TokenType.NVARCHAR,
         }
