@@ -52,6 +52,7 @@ class TokenType(AutoName):
     SCHEMA = auto()
     TABLE = auto()
     VAR = auto()
+    BIT_STRING = auto()
 
     # types
     BOOLEAN = auto()
@@ -63,7 +64,9 @@ class TokenType(AutoName):
     DOUBLE = auto()
     DECIMAL = auto()
     CHAR = auto()
+    NCHAR = auto()
     VARCHAR = auto()
+    NVARCHAR = auto()
     TEXT = auto()
     BINARY = auto()
     BYTEA = auto()
@@ -98,8 +101,6 @@ class TokenType(AutoName):
     CLUSTER_BY = auto()
     COLLATE = auto()
     COMMENT = auto()
-    COMMENT_END = auto()
-    COMMENT_START = auto()
     COMMIT = auto()
     CONSTRAINT = auto()
     CONVERT = auto()
@@ -145,11 +146,13 @@ class TokenType(AutoName):
     IGNORE_NULLS = auto()
     ILIKE = auto()
     IN = auto()
+    INDEX = auto()
     INNER = auto()
     INSERT = auto()
     INTERSECT = auto()
     INTERVAL = auto()
     INTO = auto()
+    INTRODUCER = auto()
     IS = auto()
     ISNULL = auto()
     JOIN = auto()
@@ -268,19 +271,31 @@ class _Tokenizer(type):
     def __new__(cls, clsname, bases, attrs):
         klass = super().__new__(cls, clsname, bases, attrs)
 
-        klass.QUOTES = [
-            prefix + quote for prefix in ["", "r"] for quote in klass.QUOTES
-        ]
+        klass.QUOTES = dict(
+            (quote, quote) if isinstance(quote, str) else (quote[0], quote[1])
+            for quote in klass.QUOTES
+        )
+
+        klass.IDENTIFIERS = dict(
+            (identifier, identifier)
+            if isinstance(identifier, str)
+            else (identifier[0], identifier[1])
+            for identifier in klass.IDENTIFIERS
+        )
+
+        klass.COMMENTS = dict(
+            (comment, None) if isinstance(comment, str) else (comment[0], comment[1])
+            for comment in klass.COMMENTS
+        )
 
         klass.KEYWORD_TRIE = new_trie(
             key.upper()
             for key, value in {
                 **klass.KEYWORDS,
+                **{comment: TokenType.COMMENT for comment in klass.COMMENTS},
                 **{quote: TokenType.QUOTE for quote in klass.QUOTES},
             }.items()
-            if value in (TokenType.COMMENT, TokenType.COMMENT_START, TokenType.QUOTE)
-            or " " in key
-            or any(single in key for single in klass.SINGLE_TOKENS)
+            if " " in key or any(single in key for single in klass.SINGLE_TOKENS)
         )
 
         return klass
@@ -314,15 +329,22 @@ class Tokenizer(metaclass=_Tokenizer):
         "?": TokenType.PLACEHOLDER,
         "#": TokenType.ANNOTATION,
         "$": TokenType.DOLLAR,
+        # used for breaking a var like x'y' but nothing else
+        # the token type doesn't matter
+        "'": TokenType.QUOTE,
+        "`": TokenType.IDENTIFIER,
+        '"': TokenType.IDENTIFIER,
     }
 
     QUOTES = ["'"]
 
+    IDENTIFIERS = ['"']
+
+    ESCAPE = "'"
+
     KEYWORDS = {
         "/*+": TokenType.HINT,
-        "--": TokenType.COMMENT,
-        "/*": TokenType.COMMENT_START,
-        "*/": TokenType.COMMENT_END,
+        "*/": TokenType.HINT,
         "==": TokenType.EQ,
         "::": TokenType.DCOLON,
         "||": TokenType.DPIPE,
@@ -402,6 +424,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "ILIKE": TokenType.ILIKE,
         "IGNORE NULLS": TokenType.IGNORE_NULLS,
         "IN": TokenType.IN,
+        "INDEX": TokenType.INDEX,
         "INNER": TokenType.INNER,
         "INSERT": TokenType.INSERT,
         "INTERVAL": TokenType.INTERVAL,
@@ -507,7 +530,11 @@ class Tokenizer(metaclass=_Tokenizer):
         "DOUBLE": TokenType.DOUBLE,
         "JSON": TokenType.JSON,
         "CHAR": TokenType.CHAR,
+        "NCHAR": TokenType.NCHAR,
         "VARCHAR": TokenType.VARCHAR,
+        "VARCHAR2": TokenType.VARCHAR,
+        "NVARCHAR": TokenType.NVARCHAR,
+        "NVARCHAR2": TokenType.NVARCHAR,
         "STRING": TokenType.TEXT,
         "TEXT": TokenType.TEXT,
         "BINARY": TokenType.BINARY,
@@ -547,14 +574,10 @@ class Tokenizer(metaclass=_Tokenizer):
     NUMERIC_LITERALS = {}
     ENCODE = None
 
-    COMMENTS = {"--"}
-    COMMENT_START = "/*"
-    COMMENT_END = "*/"
+    COMMENTS = ["--", ("/*", "*/")]
     KEYWORD_TRIE = None  # autofilled
 
     __slots__ = (
-        "identifiers",
-        "escape",
         "sql",
         "size",
         "tokens",
@@ -567,20 +590,10 @@ class Tokenizer(metaclass=_Tokenizer):
         "_peek",
     )
 
-    def __init__(
-        self,
-        identifiers=None,
-        escape=None,
-    ):
+    def __init__(self):
         """
         Tokenizer consumes a sql string and produces an array of :class:`~sqlglot.tokens.Token`
-
-        Args
-            identifiers (dict): keys are the identifer start characters and values are the identifier end characters
-            escape (str): the escape code character
         """
-        self.identifiers = identifiers or {'"': '"'}
-        self.escape = escape or "'"
         self.reset()
 
     def reset(self):
@@ -609,12 +622,14 @@ class Tokenizer(metaclass=_Tokenizer):
                 break
 
             white_space = self.WHITE_SPACE.get(self._char)
-            identifier_end = self.identifiers.get(self._char)
+            identifier_end = self.IDENTIFIERS.get(self._char)
 
             if white_space:
                 if white_space == TokenType.BREAK:
                     self._col = 1
                     self._line += 1
+            elif self._char == "0" and self._peek == "x":
+                self._scan_hex()
             elif self._char.isdigit():
                 self._scan_number()
             elif identifier_end:
@@ -704,32 +719,36 @@ class Tokenizer(metaclass=_Tokenizer):
             self._scan_var()
             return
 
-        if self._scan_comment(word):
-            return
         if self._scan_string(word):
             return
+        if self._scan_comment(word):
+            return
 
         self._advance(size - 1)
         self._add(self.KEYWORDS[word.upper()])
 
-    def _scan_comment(self, comment):
-        if comment in self.COMMENTS:
-            while not self._end and self.WHITE_SPACE.get(self._peek) != TokenType.BREAK:
-                self._advance()
-            return True
+    def _scan_comment(self, comment_start):
+        if comment_start not in self.COMMENTS:
+            return False
 
-        if comment == self.COMMENT_START:
-            comment_end_size = len(self.COMMENT_END)
-            while not self._end and self._chars(comment_end_size) != self.COMMENT_END:
+        comment_end = self.COMMENTS[comment_start]
+
+        if comment_end:
+            comment_end_size = len(comment_end)
+
+            while not self._end and self._chars(comment_end_size) != comment_end:
                 self._advance()
             self._advance(comment_end_size - 1)
-            return True
-
-        return False
+        else:
+            while not self._end and self.WHITE_SPACE.get(self._peek) != TokenType.BREAK:
+                self._advance()
+        return True
 
     def _scan_annotation(self):
         while (
-            not self._end and self._peek not in self.WHITE_SPACE and self._peek != ","
+            not self._end
+            and self.WHITE_SPACE.get(self._peek) != TokenType.BREAK
+            and self._peek != ","
         ):
             self._advance()
         self._add(TokenType.ANNOTATION, self._text[1:])
@@ -765,26 +784,37 @@ class Tokenizer(metaclass=_Tokenizer):
             else:
                 return self._add(TokenType.NUMBER)
 
-    def _scan_string(self, quote):
-        if quote not in self.QUOTES:
-            return False
-
-        size = len(quote)
-        text = ""
-        self._advance(size)
-
-        if quote.startswith("r"):
-            quote = quote[1:]
-            size = len(quote)
+    def _scan_hex(self):
+        self._advance()
 
         while True:
-            if self._char == self.escape and self._peek == quote:
+            char = self._peek.strip()
+            if char and char not in self.SINGLE_TOKENS:
+                self._advance()
+            else:
+                break
+        try:
+            self._add(TokenType.BIT_STRING, f"{int(self._text, 16):b}")
+        except ValueError:
+            self._add(TokenType.IDENTIFIER)
+
+    def _scan_string(self, quote):
+        quote_end = self.QUOTES.get(quote)
+        if quote_end is None:
+            return False
+
+        text = ""
+        self._advance(len(quote))
+        quote_end_size = len(quote_end)
+
+        while True:
+            if self._char == self.ESCAPE and self._peek == quote_end:
                 text += quote
                 self._advance(2)
             else:
-                if self._chars(size) == quote:
-                    if size > 1:
-                        self._advance(size - 1)
+                if self._chars(quote_end_size) == quote_end:
+                    if quote_end_size > 1:
+                        self._advance(quote_end_size - 1)
                     break
 
                 if self._end:
@@ -795,7 +825,7 @@ class Tokenizer(metaclass=_Tokenizer):
                 self._advance()
 
         text = text.encode(self.ENCODE).decode(self.ENCODE) if self.ENCODE else text
-        text = text.replace("\\\\", "\\") if self.escape == "\\" else text
+        text = text.replace("\\\\", "\\") if self.ESCAPE == "\\" else text
         self._add(TokenType.STRING, text)
         return True
 
